@@ -120,10 +120,25 @@ try:
 
                 # Numbers
                 (
-                    r'0[bB][01](_?[01])*[jJiI]?|0[oO][0-7](_?[0-7])*[jJiI]?|0[xX][0-9a-fA-F](_?[0-9a-fA-F])*[jJiI]?|((?'
-                    r':[0-9](_?[0-9])*)?\\.[0-9](_?[0-9])*|[0-9](_?[0-9])*\\.)([eE][+-]?[0-9](_?[0-9])*)?[jJiI]?|[0-9]('
-                    r'_?[0-9])*([eE][+-]?[0-9](_?[0-9])*)[jJiI]?|[0-9](_?[0-9])*[jJiI]?',
-                    Number
+                    r'0[bB][01](_?[01])*[jJiI]?',
+                    Number.Binary
+                ),
+                (
+                    r'0[oO][0-7](_?[0-7])*[jJiI]?',
+                    Number.Octal
+                ),
+                (
+                    r'0[xX][0-9a-fA-F](_?[0-9a-fA-F])*[jJiI]?',
+                    Number.Hex
+                ),
+                (
+                    r'((?:[0-9](_?[0-9])*)?\.[0-9](_?[0-9])*|[0-9](_?[0-9])*\.)([eE][+-]?[0-9](_?[0-9])*)?[jJiI]?|[0-9]'
+                    r'(_?[0-9])*([eE][+-]?[0-9](_?[0-9])*)[jJiI]?',
+                    Number.Float
+                ),
+                (
+                    r'[0-9](_?[0-9])*[jJiI]?',
+                    Number.Integer
                 ),
 
                 # Comments
